@@ -5,6 +5,7 @@ import skyview.survey.Image;
 import skyview.executive.Settings;
 
 import java.util.HashMap;
+import skyview.survey.Survey;
 
 /** Find contours of an image.  */
 public class Contourer {
@@ -90,7 +91,8 @@ public class Contourer {
 	    System.err.println("  Contour requesting image from survey "+
 		survey);
 	    Settings.put("preprocessor", "null");
-	    img = imager.loadAndProcessSurvey(survey);
+            Survey surv = imager.loadSurvey(survey);
+	    img = imager.doProcessSurvey(survey, surv);
 	    String[] posts   = Settings.getArray("postprocessor");
 	    String[] fposts = Settings.getArray("finalpostprocessor");
            
@@ -116,7 +118,7 @@ public class Contourer {
 		   if (copy == null) {
 		       copy  = img.getDataArray().clone();
 		   }
-			imager.dynoProcess(posts[i]);
+			imager.dynoProcess(posts[i], null);
 		}
 	    }
 	    
