@@ -1333,6 +1333,8 @@ public class Imager {
     private WCS copyWCS(String file) throws Exception {
 	// This should only read the first header of the file.
 	Header hdr     = new Header(new Fits(file).getStream());
+        lon = hdr.getDoubleValue("CRVAL1");
+        lat = hdr.getDoubleValue("CRVAL2");
 	return new WCS(hdr);
     }
     
