@@ -536,7 +536,7 @@ public class Spline extends skyview.geometry.Sampler {
 	    yIndex[k] = (inHeight == 1) ? (0) : ((yIndex[k] < 0) ?
 						   (-yIndex[k] - Height2 * ((-yIndex[k]) / Height2))
 						 : (yIndex[k] - Height2 * (yIndex[k] / Height2)));
-	    if (inWidth <= yIndex[k]) {
+	    if (inHeight <= yIndex[k]) {
 		yIndex[k] = Height2 - yIndex[k];
 	    }
 	}
