@@ -13,7 +13,7 @@ import nom.tam.fits.Header;
  * Currently this is a MedianEdgeDeedger
  */
 
-public class Deedger implements Processor {
+public class Deedger extends Processor {
     
     
     /** The object that will do all the work.
@@ -25,6 +25,10 @@ public class Deedger implements Processor {
 	return stdDeedger.getName();
     }
     
+    public boolean updatesOutput() {
+        return true;
+    }
+    
     public String getDescription() {
 	return stdDeedger.getDescription();
     }
