@@ -22,16 +22,30 @@ public class CGIInitiator {
    
   // Keywords not permitted for user in CGI request.
   private static Set<String> forbiddenKeys = new HashSet<String>(); 
+  private static Set<String> restrictedKeys = new HashSet<String>();
   private static String[] fka = {
-    "output", "headertemplate", "footertemplate",
+    "output", "footertemplate",
     "userfile", "surveyxslt", "xmlroot", "xmlfileprefix",
-    "cache", "drawfile", "file", "siaheader",
-    "webrootpath", };
+    "cache", "file", "siaheader",
+    "webrootpath" };
+  
+  private static String[] rka = {
+      "headertemplate", "footertemplate", "surveytemplate", "drawfile"
+  };
+  
+  private static String[] allowedPrefix = {"/skyview/local/userdata/"};
+
   static {
       for (String key: fka) {
           forbiddenKeys.add(key);
       }
+      for (String key: rka) {
+          restrictedKeys.add(key);
+      }
+            
   }
+  
+  
 
    public static void main(String[] args) {
 
@@ -114,6 +128,27 @@ public class CGIInitiator {
                 continue;  // Skip this one
             }
             
+            if (restrictedKeys.contains(lkey)) {
+                if (!lkey.matches("[a-zA-Z0-9./_]*")) {
+                    System.err.println("Invalid restricted key:"+key);
+                    continue;
+                }
+                boolean matched = false;
+                String[] values = params.values(key);
+                if (values.length == 1) {
+                    for (int i = 0; i<allowedPrefix.length; i += 1) {
+                        if (values[0].startsWith(allowedPrefix[i])) {
+                            matched = true;
+                            break;
+                        }
+                    }
+                }
+                if (!matched) {
+                    System.err.println("Restricted key used out of allowed context:"+lkey);
+                    continue;
+                }
+            }
+            
             String[] values = params.values(key);
             boolean first = true;
 
