@@ -65,7 +65,7 @@ public class DSSImage extends Image {
 	}
 	
 	initialize(null, w, xSize, ySize, 1);
-	setName(plate);
+	setName(directory);
     }
     
     /** Get a pixels data associated with the image. */
