@@ -151,11 +151,11 @@ public class Image implements skyview.Component {
 	return center;
     }
     
-    private double[][] corners = new double[2][4];
     
     /** Get the corners of the given output pixel */
     public double[][] getCorners(int npix) {
 	
+        double[][] corners = new double[2][4];
 	corners[0][0] = npix%nx;
 	corners[1][0] = npix/nx;
 	corners[0][1] = corners[0][0] + 1;
