@@ -175,11 +175,15 @@ public class NewTester {
         }
 
         // Get any old information about tests.
-        if (new File("comparison.settings").exists()) {
-            Settings.updateFromFile("comparison.settings");
-        }
-        for (String key : Settings.getKeys()) {
-            oldResults.put(key, Settings.get(key));
+        // Skip this if the NO_COMPARISON environment variable is set.
+        
+        if (System.getenv("NO_COMPARISON") == null) {
+            if (new File("comparison.settings").exists()) {
+                Settings.updateFromFile("comparison.settings");
+            }
+            for (String key : Settings.getKeys()) {
+                oldResults.put(key, Settings.get(key));
+            }
         }
 
         // Set up a file giving information about results.  Append to
@@ -211,8 +215,6 @@ public class NewTester {
             "wfcf1", "wfcf2", "euve83", "euve171", "euve405", "euve555",
             "neat", "rass-int broad", "rass-int hard", "rass-int soft",
             "wisew1", "wisew2", "wisew3", "wisew4",
-            "planck-030", "planck-044", "planck-070", "planck-100",
-            "planck-143", "planck-217", "planck-353", "planck-545", "planck-857",
             "EBHIS",
             "TGSS ADR1", 
             "AKARI N60", "AKARI WIDE-S", "AKARI WIDE-L", "AKARI N160",
@@ -225,6 +227,14 @@ public class NewTester {
             "UVOT UVM2 Exposure", "UVOT UVW2 Exposure",
             "GLEAM 72-103", "GLEAM 103-134", "GLEAM 139-170", "GLEAM 170-231"
         };
+        
+        String[] planckBase = new String[]{
+            "planck-030", "planck-044", "planck-070", "planck-100",
+            "planck-143", "planck-217", "planck-353"
+
+        };
+        
+        String[] planckSuffix = new String[]{"I", "Q", "U", "PI", "PA", "PI/I"};
 
         // Mellinger survey is done twice so that
         // we get full resolution and lower resolution images.
@@ -238,7 +248,7 @@ public class NewTester {
             "wmapk", "wmapka", "wmapq", "wmapv", "wmapw", "wmapilc",
             "mell-r", "mell-g", "mell-b",
             "intgal1735f", "intgal1760f", "intgal3580f", "intgal1735e", "intgal1735s",
-	    "HI4PI"
+	    "HI4PI", "22Mhz"
         };
 
         String[] gc = new String[]{
@@ -424,7 +434,25 @@ public class NewTester {
             currentSettings.put("survey", survey);
             test(true);
         }
-
+        
+        base.up();
+        base.down();
+        // Planck Surveys
+        currentSettings.put("position", "187.25, 2.05");
+        currentSettings.put("Coordinates", "Galactic");
+        for (String base: planckBase) {
+            currentSettings.put("Size", "5");
+            for (String suffix: planckSuffix) {
+                String survey = base+" "+suffix;
+                currentSettings.put("Survey", survey);
+                test(true);
+            }
+        }
+        // High frequency bands have no polarization data.
+        for (String name: new String[]{"planck-545 I", "planck-857 I"}) {
+            currentSettings.put("Survey", name);
+            test(true);
+        }
     }
 
     public int jpegSum(String jpegName) throws Exception {
@@ -754,7 +782,7 @@ public class NewTester {
 
         currentSettings.clear();
 
-        String[] projections = {"Tan", "Sin", "Car", "Ait", "Csc", "Zea", "Arc", "Stg", "Sfl", "Hpx", "Tea"};
+        String[] projections = {"Tan", "Sin", "Car", "Ait", "Csc", "Zea", "Arc", "Stg", "Sfl", "Hpx", "Tea", "Mol"};
 
         currentSettings.put("Survey", "heao1a");
         currentSettings.put("Coordinates", "Galactic");
